@@ -277,7 +277,8 @@ class TransformerTask:
 
     def single_predict(self, example: InputExample):
         data_processor = DataProcessor()
-        data_processor.get_dev_examples = lambda s: [example]
+        data_processor.get_dev_examples = lambda: [example]
+        data_processor.get_labels = lambda: []
         return self.predict(data_processor)
 
     def predict(self, data_processor=None) -> PredictionOutput:
